Summary: Utilities for managing the second extended (ext2) filesystem.
Name: e2fsprogs
Version: 1.35
Release: 3tr
License: GPL
Group: Trustix Official
Source: http://belnet.dl.sourceforge.net/sourceforge/%{name}/%{name}-%{version}.tar.gz
URL: http://e2fsprogs.sourceforge.net/ext2.html
Prereq: glibc
Requires: libcom_err
Buildroot: %{_tmppath}/%{name}-root

%description
The e2fsprogs package contains a number of utilities for creating,
checking, modifying and correcting any inconsistencies in second
extended (ext2) filesystems.  E2fsprogs contains e2fsck (used to repair
filesystem inconsistencies after an unclean shutdown), mke2fs (used to
initialize a partition to contain an empty ext2 filesystem), debugfs
(used to examine the internal structure of a filesystem, to manually
repair a corrupted filesystem or to create test cases for e2fsck), tune2fs
(used to modify filesystem parameters) and most of the other core ext2fs
filesystem utilities.

You should install the e2fsprogs package if you are using any ext2
filesystems (if you're not sure, you probably should install this
package).

%package devel
Summary: Ext2 filesystem-specific static libraries and headers.
Group: Trustix Official
Requires: e2fsprogs

%description devel
E2fsprogs-devel contains the libraries and header files needed to
develop second extended (ext2) filesystem-specific programs.

You should install e2fsprogs-devel if you want to develop ext2
filesystem-specific programs.  If you install e2fsprogs-devel, you'll
also need to install e2fsprogs.

%package -n libcom_err
Group: Trustix Official
Summary: Com_err library

%description -n libcom_err
Com_err is an error message display library.

%package -n libcom_err-devel
Group: Trustix Official
Summary: Com_err Development library

%description -n libcom_err-devel
Com_err is an error message display library, development files.

%prep
%setup -q

%build
CFLAGS="$RPM_OPT_FLAGS" \
%configure \
	--prefix=/ \
	--enable-elf-shlibs \
	--libdir=/lib \
        --sbindir=/sbin

make libs progs

%install
[ -n "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != "/" ] && rm -rf "$RPM_BUILD_ROOT"
export PATH=/sbin:$PATH
make install install-libs DESTDIR="$RPM_BUILD_ROOT"

# Seems there is no easy way of making this split
mkdir -p $RPM_BUILD_ROOT/usr/lib
mv $RPM_BUILD_ROOT/lib/*.a $RPM_BUILD_ROOT/usr/lib/
mv $RPM_BUILD_ROOT/lib/evms/ $RPM_BUILD_ROOT/usr/lib/
pushd $RPM_BUILD_ROOT/lib
  for i in *.so; do
    cp $i.[0-9].[0-9] $RPM_BUILD_ROOT/usr/lib/$i
    rm -f $i
  done
popd


%clean
[ -n "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != / ] && rm -rf $RPM_BUILD_ROOT

%post
/sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc README RELEASE-NOTES
/sbin/*
/lib/libss.so.*
/lib/libe2p.so.*
/lib/libext2fs.so.*
/lib/libuuid.so.*
/lib/libblkid.so.*
%{_bindir}/chattr
%{_bindir}/lsattr
%{_bindir}/uuidgen
/usr/share/man/man1/chattr.1*
/usr/share/man/man1/lsattr.1*
/usr/share/man/man1/uuidgen.1*
/usr/share/man/man8/*

%files devel
%defattr(-,root,root)
/usr/bin/mk_cmds
/usr/lib/libblkid.a
/usr/lib/libe2p.a
/usr/lib/libext2fs.a
/usr/lib/libss.a
/usr/lib/libuuid.a
/usr/lib/evms
/usr/lib/libblkid.so
/usr/lib/libe2p.so
/usr/lib/libext2fs.so
/usr/lib/libss.so
/usr/lib/libuuid.so
/usr/share/ss
/usr/include/ss
/usr/include/ext2fs
/usr/include/uuid
/usr/include/blkid
/usr/include/e2p
/usr/share/man/man3/*
/usr/share/man/man1/mk_cmds.1.gz

%files -n libcom_err
%defattr(0755,root,root)
/lib/libcom_err.so.2.1
/lib/libcom_err.so.2

%files -n libcom_err-devel
%defattr(0755,root,root)
%{_bindir}/compile_et
%{_datadir}/et
%{_mandir}/man1/compile_et.1.gz
%{_libdir}/libcom_err.a
%{_libdir}/libcom_err.so
%{_includedir}/et


%changelog
* Tue Mar  2 2004 Erlend Midttun <erlendbm at trustix dot org> 1.35-2tr
- Rebuilt.

* Tue Mar  2 2004 Omar Kilani <ok at trustix dot org> 1.35-1ok
- New upstream.

* Mon Feb  9 2004 Chr. Toldnes <christht at trustix dot org> 1.34-2tr
- libcom_err in separate packages.

* Tue Jan 27 2004 Erlend Midttun <erlendbm at trustix dot org> 1.34-1tr
- New upstream.

* Wed Nov 26 2003 Erlend Midttun <erlendbm at trustix dot com> 1.33-3tr
- Big rebuild

* Wed Jun 18 2003 Erlend Midttun <erlendbm at trustix dot com> 1.33-2tr
- Big rebuild

* Fri May 23 2003 Erlend Midttun <erlendbm at trustix dot com> 1.33-1em
- New upstream.

* Mon Mar 24 2003 Erlend Midttun <erlendbm at trustix dot com> 1.27-3em
- Rebuilt against glibc 2.3.2.

* Thu Aug 29 2002 Christian H. Toldnes <christht at trustix dot com> 1.27-2ct
- Patched away info generation

* Thu Jul  4 2002 Christian H. Toldnes <christht at trustix dot com> 1.27-1ct
- New upstream version
- Spec file cleanup
- Removed info stuff
- Built for TSL 2.0

* Mon Jan 14 2002 Christian H. Toldnes <christht at trustix dot com>
- New upstream version: 1.25

* Wed Jul  4 2001 Erlend Midttun <erlendbm at trustix dot com>
- New upstream version: 1.22

* Fri Jun  1 2001 Oystein Viggen <oysteivi at trustix dot com>
- New upstream version: 1.20

* Wed Sep 13 2000 Erlend Midttun <erlendbm at trustix dot com>
- Updated to 1.19

* Wed Mar 15 2000 Oystein Viggen <oysteivi at trustix dot com>
- Fixed some bugs with placement of files.

* Mon Feb 28 2000 Lars Gaarden <larsg at trustix dot com>
- Moved man and info pages to /usr/share


